@@ -3,6 +3,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "settings_proxy.h"
+#include "base/ddlog.h"
 
 #include <QtGui/QDesktopServices>
 #include <QUrl>
@@ -10,5 +11,6 @@
 SettingsProxy::SettingsProxy(QObject *parent)
     : QObject(parent)
 {
+    qCDebug(app) << "SettingsProxy constructor called";
     this->setObjectName("SettingsProxy");
 }
