@@ -3,6 +3,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "view/widget/image_viewer.h"
+#include "base/ddlog.h"
 
 #include <DLog>
 #include <QApplication>
@@ -24,14 +25,17 @@ const int kCloseBtnSize = 48;
 ImageViewer::ImageViewer(QWidget *parent)
     : QDialog(parent)
 {
+    qCDebug(app) << "ImageViewer constructor called";
     this->setObjectName("ImageViewer");
     this->initUI();
 
     connect(close_button_, &Dtk::Widget::DIconButton::clicked, this, &ImageViewer::close);
+    qCDebug(app) << "ImageViewer constructor done";
 }
 
 ImageViewer::~ImageViewer()
 {
+    qCDebug(app) << "ImageViewer destructor called";
 }
 
 /**
@@ -41,26 +45,27 @@ ImageViewer::~ImageViewer()
  */
 void ImageViewer::open(const QString &filepath)
 {
-    qDebug() << Q_FUNC_INFO << filepath;
+    qCDebug(app) << filepath;
 
     // Escape uri.
     QString abspath(filepath);
     if (abspath.contains("://")) {
         QUrl url(abspath);
         abspath = url.path();
+        qCDebug(app) << "Extracted path from URL:" << abspath;
     }
     QImage image;
     QImageReader reader(abspath);
     reader.setDecideFormatFromContent(true);
     if (reader.canRead()) {
         if (reader.read(&image)) {
-            qDebug() << "image open is successful....";
+            qCDebug(app) << "image open is successful....";
         } else {
-            qDebug() << "image open is failed...." << reader.errorString();
+            qCDebug(app) << "image open is failed...." << reader.errorString();
         }
 
     } else {
-        qDebug() << "can not read...." << reader.errorString();
+        qCDebug(app) << "can not read...." << reader.errorString();
     }
 #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     const QRect screen_rect = qApp->desktop()->screenGeometry(QCursor::pos());
@@ -71,11 +76,14 @@ void ImageViewer::open(const QString &filepath)
     const int pixmap_max_height = static_cast<int>(screen_rect.height() * 0.8);
 
     if ((image.width() > pixmap_max_width) || (image.height() > pixmap_max_height)) {
+        qCDebug(app) << "Scaling image from" << image.size()
+                    << "to max" << pixmap_max_width << "x" << pixmap_max_height;
         image = image.scaled(pixmap_max_width, pixmap_max_height, Qt::KeepAspectRatio,
                              Qt::SmoothTransformation);
     }
     //小图标不点击放大
     if (image.width() < 50 && image.height() < 50) {
+        qCDebug(app) << "Skipping small image:" << image.size();
         return;
     }
     this->move(screen_rect.topLeft());
@@ -96,6 +104,7 @@ void ImageViewer::open(const QString &filepath)
                         top_right_point.y() - kCloseBtnSize / 2);
     close_button_->show();
     close_button_->raise();
+    qCDebug(app) << "ImageViewer opened:" << filepath;
 }
 
 /**
@@ -104,6 +113,7 @@ void ImageViewer::open(const QString &filepath)
  */
 void ImageViewer::initUI()
 {
+    qCDebug(app) << "Initializing ImageViewer UI";
     img_label_ = new DLabel(this);
     img_label_->setObjectName("ImageLabel");
 
@@ -126,9 +136,11 @@ void ImageViewer::initUI()
     scHideDialog->setAutoRepeat(false);
 
     connect(scHideDialog, &QShortcut::activated, this, [this] {
-        qDebug() << "pressed esc!";
+        qCDebug(app) << "pressed esc!";
         this->hide();
     });
+
+    qCDebug(app) << "UI initialization completed";
 }
 
 /**
@@ -138,8 +150,10 @@ void ImageViewer::initUI()
  */
 void ImageViewer::mousePressEvent(QMouseEvent *event)
 {
+    qCDebug(app) << "Mouse press event";
     QWidget::mousePressEvent(event);
     this->hide();
+    qCDebug(app) << "Image viewer hidden by mouse click";
 }
 
 /**
