@@ -4,127 +4,127 @@
 <context>
     <name>ManualProxy</name>
     <message>
-        <location filename="../src/view/manual_proxy.cpp" line="322"/>
+        <location filename="../src/view/manual_proxy.cpp" line="363"/>
         <source>Learn Basic Operations</source>
-        <translation type="unfinished"></translation>
+        <translation>Μάθε Βασικές Επιχειρήσεις</translation>
     </message>
     <message>
-        <location filename="../src/view/manual_proxy.cpp" line="324"/>
+        <location filename="../src/view/manual_proxy.cpp" line="366"/>
         <source>Common Application Libraries</source>
-        <translation type="unfinished"></translation>
+        <translation>Συνήθεις Βιβλιοθήκες Εφαρμογών</translation>
     </message>
     <message>
-        <location filename="../src/view/manual_proxy.cpp" line="326"/>
+        <location filename="../src/view/manual_proxy.cpp" line="369"/>
         <source>Desktop Environment</source>
-        <translation type="unfinished"></translation>
+        <translation>Περιβάλλον Επιφάνειας Εργασίας</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../src/view/widget/search_completion_window.cpp" line="163"/>
-        <location filename="../src/view/widget/search_completion_window.cpp" line="249"/>
-        <source>Search for &quot;%1&quot; in the full text</source>
-        <translation type="unfinished"></translation>
+        <location filename="../src/view/widget/search_completion_window.cpp" line="197"/>
+        <source>Search for "%1" in the full text</source>
+        <translation>Αναζήτηση του "%1" στο πλήρες κείμενο</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="301"/>
+        <location filename="../src/view/web_window.cpp" line="363"/>
         <source>The content was updated</source>
-        <translation type="unfinished"></translation>
+        <translation>Το περιεχόμενο ενημερώθηκε</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="624"/>
+        <location filename="../src/view/web_window.cpp" line="767"/>
         <source>Search</source>
         <translation>Αναζήτηση</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="627"/>
-        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="35"/>
         <source>Support</source>
-        <translation type="unfinished"></translation>
+        <translation>Υποστήριξη</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="836"/>
+        <location filename="../src/view/web_window.cpp" line="1038"/>
         <source>Copy</source>
         <translation>Αντιγραφή</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="21"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
         <source>Quick Start</source>
-        <translation type="unfinished"></translation>
+        <translation>Γρήγορη Εκκίνηση</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="22"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
         <source>Video Guide</source>
-        <translation type="unfinished"></translation>
+        <translation>Βίντεο Οδηγός</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="23"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
         <source>System</source>
         <translation>Σύστημα</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="24"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
         <source>Applications</source>
         <translation>Εφαρμογές</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
         <source>No search results</source>
-        <translation type="unfinished"></translation>
+        <translation>Δεν υπάρχουν αποτελέσματα αναζήτησης</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
         <source>Home</source>
         <translation>Αρχική</translation>
     </message>
     <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
+        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
         <source>  result</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
-        <source>  results</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
-        <source>Click to view </source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
-        <source>View all</source>
-        <translation type="unfinished"></translation>
+        <translation> αποτέλεσμα</translation>
     </message>
     <message>
         <location filename="../src/view/i18n_proxy.cpp" line="32"/>
+        <source>  results</source>
+        <translation> αποτελέσματα</translation>
+    </message>
+    <message>
+        <location filename="../src/view/i18n_proxy.cpp" line="33"/>
+        <source>Click to view </source>
+        <translation>Κάντε κλικ για να δείτε </translation>
+    </message>
+    <message>
+        <location filename="../src/view/i18n_proxy.cpp" line="34"/>
+        <source>View all</source>
+        <translation>Προβολή όλων</translation>
+    </message>
+    <message>
+        <location filename="../src/view/i18n_proxy.cpp" line="36"/>
         <source>App Store</source>
-        <translation type="unfinished"></translation>
+        <translation>Αγορά Εφαρμογών</translation>
     </message>
     <message>
-        <location filename="../src/app/dman.cpp" line="105"/>
+        <location filename="../src/app/dman.cpp" line="136"/>
         <source>Manual</source>
-        <translation type="unfinished"></translation>
+        <translation>Εγχειρίδιο</translation>
     </message>
     <message>
-        <location filename="../src/app/dman.cpp" line="106"/>
+        <location filename="../src/app/dman.cpp" line="137"/>
         <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
-        <translation type="unfinished"></translation>
+        <translation>>-
+ Το εγχειρίδιο σχεδιάστηκε για να βοηθήσει τους χρήστες να μάθουν το σύστημα λειτουργιών και τις
+ εφαρμογές του, παρέχοντας συγκεκριμένες οδηγίες και περιγραφές λειτουργιών.</translation>
     </message>
 </context>
 <context>
     <name>WebWindow</name>
     <message>
-        <location filename="../src/view/web_window.cpp" line="765"/>
+        <location filename="../src/view/web_window.cpp" line="952"/>
         <source>Ctrl+Alt+F</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+Alt+F</translation>
     </message>
     <message>
-        <location filename="../src/view/web_window.cpp" line="780"/>
+        <location filename="../src/view/web_window.cpp" line="969"/>
         <source>Ctrl+F</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+F</translation>
     </message>
 </context>
 </TS>
